"""
Tests for the `acv_exploitation.py` module.
"""

import pytest

from colibri.interfaces import Acv
from colibri.modules import AcvExploitationOnly


def test_acv_exploitation_model() -> None:
    """Test the AcvExploitationOnly class."""
    acv: AcvExploitationOnly = AcvExploitationOnly(
        name="acv-1",
        q_consumed={"kitchen": 350},
        co2_impact=25.0,
    )
    assert isinstance(acv, AcvExploitationOnly) is True
    assert isinstance(acv, Acv) is True
    assert acv.name == "acv-1"
    assert acv.carbon_to_electricity_ratio == 70.0
    assert acv.co2_impact == 25.0
    acv.end_simulation()
    assert acv.co2_impact == pytest.approx(24_500, abs=1)
    assert acv.has_converged(time_step=1, number_of_iterations=1) is True


if __name__ == "__main__":
    test_acv_exploitation_model()
